function [ avalue kvalue jydataprocessed secondorderfit experimentref zeropoint gof ci pi] = jykineticsprocess2unnormalisedpeaktrunc( filename, bgcorrect, startpointsensitivity, mixtime, fitstoppercentage, varargin)
%jykineticsprocess2  Takes a transposed output of fluorescence data (use
%function transpose_CWA_text_file to obtain this), performs photobleaching
%correction (optional), finds the start point of a kinetics experiment, and
%performs a second order kinetics fit to the data.
%   Data should be 8 columns with even columns giving fluorescence counts
%   and odd columns giving time.  The last two columns should contain the
%   photobleaching control trace.
%
% See also transpose_CWA_text_file, merge_transposed_text_file, definecolours2, fit.





%NOTE BOUNDS ON FITTING FUNCTION

%colourcell = definecolours2(3, [1 0 1]);

% Read in data
datastruct=importdata(filename, '\t');
jydata=datastruct.data;
rawdata=jydata;
samples=datastruct.colheaders
[path experimentname]=fileparts(filename)


% figure
% plot(rawdata(:,1), rawdata(:,2),'r')
% hold on
% plot(rawdata(:,3), rawdata(:,4),'g')
% plot(rawdata(:,5), rawdata(:,6),'b')
% plot(rawdata(:,7), rawdata(:,8),'m')
% hold off

% Photobleaching background correction (divide by fluorescence in control
% sample which must be sample 4 (i.e. columns 7 and 8)
secondorderfit=zeros(length(jydata),9);
if bgcorrect==1
    
    jydata(:,2)=jydata(:,2)./jydata(:,8); 
    jydata(:,4)=jydata(:,4)./jydata(:,8);
    jydata(:,6)=jydata(:,6)./jydata(:,8);
end



% Find the startpoint of the reaction
        % First identify discontinuity in data aquisition by finding the
        % difference between adjacent timepoints
        diference=diff(jydata(:,1));
        nonzerodiference=diference(diference~=0);
        timestep = mode(nonzerodiference)
        experimentref={}
        for i=1:3;
            
            sample=samples{2*i}
            graphname=[experimentname,' position ', num2str(i),': ',sample]
            if nargin<8
        pauses = diff(jydata(:,(2*i-1)))-timestep;
        pauses = abs(pauses)>0.2; % If the instrument is interrupted (for adding reactants) the hope is it will produce a time difference not equal to timestep. 0.2 provides sufficient tolerance for small variations in timestep occasionally produced by the instrument when acquiring data (particuarly for the late sample positions)
        
        pauses = padarray(pauses,[1,0],'post'); % array needs `padding' because after applying diff the data will be shortened.  One extra zero is added at the end.
        
        
        % User can add a 6th and 7th optional input to define the start and end of a window over
        % which to search for the startpoint of the reaction.  The window
        % is defined in seconds and refers to times in the original data
        % (unshifted)
        if nargin > 5
           
            %Override the start point fitting with user defined "window"
            %variable input
            windowopen=varargin{1}
            windowclose=varargin{2}
            searchstartindex= floor(windowopen/timestep)
            searchstopindex= floor(windowclose/timestep)
            pauses=zeros(length(jydata(:,1)),1);
            pauses(searchstartindex:searchstopindex)=1
            pauses=logical(pauses);
        end
        
        % For the positions where the instrument pauses (or the user
        % defined window) the maximum local rise is used to determine the
        % start of the reaction.  Input variable startpointsensistivity
        % gives the number of data points to have their differences summed to eventually find a local
        % rise
        riselocal = diff(jydata(:,(2*i))); % Differentiate fluorescence
        rise=[];
        for j=1:(length(riselocal)-startpointsensitivity)
            rise(j) = sum(riselocal(j:(j+startpointsensitivity))); % sum the differences between adjacent data points for the next startpointsensitivity data points
        end
        
        rise=rise';
        
        length(pauses)
        
      
    % find the difference between the rise (over startpointsensitivity
    % points) before a pause and the rise (over startpointsensitivity points)
    % after a pause.  The maximum difference should occur once the reaction
    % has started (i.e. the first data point of the reaction).
        fluor_later = padarray(rise,[(startpointsensitivity+1),0],'post'); % Fluorescence at a later time should be higher
        fluor_earlier = padarray(rise,[(startpointsensitivity+1),0],'pre');
        
        length(fluor_later)
        output_args = fluor_later;

        fwd_jumps = pauses.*fluor_later;
        bwd_jumps = pauses.*fluor_earlier;
        jumps = fwd_jumps-abs(bwd_jumps);
        
        startpointindex = find(jumps == max(jumps((3*startpointsensitivity):(end-3*startpointsensitivity))))

        
        

        
        
        
        end    
                
        % User can add an 8th optional input (with format [x y z]) to define the start index
        % exactly.  The 6th and 7th input arguments must be entered but are
        % effectively meaningless at this point.
       if nargin > 7
       %override the startpoint with the user input index for the zeropoint
       userzeropoint=varargin{3};
       startpointindex=userzeropoint(i)
       end
       
       
        
        
        
        
        experimentstart=jydata(startpointindex,(2*i-1))
        startrawfluor=jydata(startpointindex,(2*i))

     
        
        
        

        
        figure('name', graphname)
%         plot(jydata((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i-1)),fwd_jumps(2*startpointsensitivity:(end-2*startpointsensitivity)))
%         hold on
%         plot(jydata((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i-1)),jydata((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i)),'r')
%         ylim([0 1.2])
%         hold off



       %$$fitend=min(length(jydata(:,1)),floor(fitstop/60))
        
       
       
       
       
       
        

       
       
       
       
       
       
       
       
       
       
        % Now that the start point has been determined it is zeroed (with
        % the user input mixing time as an offset).  The zero point for
        % fluorescence is assumed to be the fluorescence at the point
        % immediately before the start point.
        
        jydataprocessed(:,(2*i-1))=jydata(:,(2*i-1))-jydata(startpointindex,(2*i-1))+mixtime;
        jydataprocessed(:,(2*i))=jydata(:,(2*i))-jydata(startpointindex-1,(2*i));
        

        %figure
        plot(jydataprocessed((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i-1)),jydataprocessed((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i)))
        title(graphname);
        xlabel('Time (s)');
        ylabel('Fluorescence (a.u.)');

        % Performing second order fit using MATLAB function 'fit'
        %
        % Bounds and initial conditions for fit: 
        % Start time for fit determined as above using stepfinder
        %
        % User defined end time for the fit 'fitstop' (relative to
        % times in original file (unshifted) or the last data point,
        % whichever comes first.
        %
        % a is limited to be within 0.9 times the maximum recorded
        % fluorescence value and 1.5 times the maximum recorded
        % fluorescence value.
        %
        % a is initiallised as the maximum recorded fluorescence value
        %
        % k is limited to be between 0 and 1000
        %
        % k is initiallised as 1e-3
       zeropoint(i)=startpointindex
       experimentstarttime(i)=experimentstart
       fluorstart(i)=startrawfluor
        fitstart=startpointindex;
        
        stopindex = fitstart+find(jydataprocessed(fitstart:end,2*i)>fitstoppercentage*max(jydataprocessed(:,2*i)),1);
        fitend=min(length(jydata(:,1)),stopindex);
       
        FTYP=fittype(@(a,k, x) a-a./(1+k*x), 'coefficients', {'a','k'});
        %FTYP=fittype(@(a,k, x) a-a./(1+a*k*x), 'coefficients', {'a','k'});
        

 if isempty(fitend)
     fitcompleted{i}='No'

 else if fitend<fitstart
     fitcompleted{i}='No'

     else
         fitcompleted{i}='Yes'
         
                 [fitted, gof]=fit(jydataprocessed(fitstart:fitend,(2*i-1)), jydataprocessed(fitstart:fitend,(2*i)), FTYP, 'Lower', [0.9*max(jydataprocessed(fitstart:fitend,(2*i))), 0], 'Upper', [1.5*max(jydataprocessed(:,(2*i))), 1000], 'StartPoint', [max(jydataprocessed(:,(2*i))), 1e-3], 'MaxIter', 10000);
                    ci{i}=confint(fitted,0.95)
                    pi{i}=predint(fitted,jydataprocessed(fitstart:fitend,(2*i-1)));
        
        
        fittedcurve=feval(fitted, jydataprocessed(fitstart:fitend,(2*i-1)));
       extrapolatedcurve=feval(fitted, jydataprocessed(fitend:end,(2*i-1)));


        
        fitnames = coeffnames(fitted);
fitparams = coeffvalues(fitted);

         
     end
 
 end








hold on
try
plot(jydataprocessed(fitstart:fitend,(2*i-1)),fittedcurve, 'Color', 'k')
plot(jydataprocessed(fitend:end,(2*i-1)),extrapolatedcurve, 'Color', 'r')
plot(jydataprocessed(fitstart:fitend,(2*i-1)), pi{i}, 'g--')


avalue(i)=fitparams(1)
text = "Fitted rate constants in units of M^-1s^-1:"
kvalue(i)=fitparams(2)/0.0000000125 %convert to units of M^-1s^-1

ylim([-avalue(i)*0.1 avalue(i)*1.1])    



secondorderfit(fitstart:fitend,3*i-2)=jydataprocessed(fitstart:fitend,(2*i-1));
secondorderfit(fitstart:fitend,3*i-1)=jydataprocessed(fitstart:fitend,(2*i));
secondorderfit(fitstart:fitend,3*i)=fittedcurve;

        hold off
        experimentref=[experimentref;{graphname}];
    
      
        secondorderfit(secondorderfit == 0) = NaN;


        end   
%fitcompleted=fitcompleted
end

figure
plot(rawdata(:,1), rawdata(:,2),'r')
hold on
plot(rawdata(:,3), rawdata(:,4),'g')
plot(rawdata(:,5), rawdata(:,6),'b')
plot(rawdata(:,7), rawdata(:,8),'m')
        plot(experimentstarttime(1), fluorstart(1), 'Color', 'r', 'Marker', 'x')
        plot(experimentstarttime(2), fluorstart(2), 'Color', 'g', 'Marker','x')
        plot(experimentstarttime(3), fluorstart(3), 'Color', 'b', 'Marker','x')
        hold off   
    

end