function [ params ] = fittwotoeholdODEs5(datafilename, samplenumber, I5_0, I3_0, VT_0, k5init,  k3init,  kplusinit, kminusinit, renorm, logweight, varargin)
%FITTWOTOEHOLDODES Summary of this function goes here
% logweight assigns weighting to fit-data distances in the fit scoring
% function.  Larger logwright gives greater weighting to early timepoints



if nargin>12
    data=plateaufix(datafilename);
else
    data=importdata(datafilename);
end

otdata=data(:,(samplenumber*4-3));
oFdata1=data(:,(samplenumber*4-2));%no longer extra normalising (unless renorm = 1)
otdata2=data(:,(samplenumber*4-1));
oFdata2=data(:,(samplenumber*4));%no longer extra normalising (unless renorm = 1)

if renorm==1
    renormalising='yes'
    normval=max(tsmovavg((oFdata1+oFdata2),'s',60,1));
    oFdata1=oFdata1./normval;
    oFdata2=oFdata2./normval;
end
ts2=timeseries(oFdata2,otdata2);
tsnew=resample(ts2,otdata);
oFdata2=tsnew.data;


Fdata2=oFdata2(otdata>0);
Fdata2(any(isnan(Fdata2),2),:)=[];
tdata=otdata(otdata>0);
tdata(any(isnan(Fdata2),2),:)=[];
Fdata1=oFdata1(otdata>0);
Fdata1(any(isnan(Fdata2),2),:)=[];

minim=min([length(Fdata2), length(tdata), length(Fdata1)]);
tdata=tdata(1:minim);
Fdata1=Fdata1(1:minim);
Fdata2=Fdata2(1:minim);

k5=k5init;
kminus5=0;
k3=k3init;
kminus3=0;
kplus=kplusinit;
kminus=kminusinit;

fitstopindex=length(Fdata1);
if nargin>11
    % This variable input is the maximum timepoint to fit the data up to.
    % It is a timepoint after zero time subtraction (i.e. the time in
    % seconds after the experiment has started)
maxtime=varargin{1};
% 	timestep=60
% 	t_stop=timestep*floor(maxtime/timestep)
whatismin=(maxtime-tdata)
fitstopindex=min(find(abs(maxtime-tdata)==min(abs(maxtime-tdata))));
% timevector=0:timestep:t_stop;
end

initfitparams=[k5init, k3init, kplusinit, kminusinit];
function [ d_by_dt ] = twotoeholdODEs( t, F)
d_by_dt = zeros(2,1);
d_by_dt(1) = -kminus5*(F(1)+F(2))*F(1)+k5*(VT_0-F(1)-F(2))*(I5_0-F(1))-kplus*(I3_0-F(2))*F(1)+kminus*(I5_0-F(1))*F(2);
d_by_dt(2) = -kminus3*(F(1)+F(2))*F(2)+k3*(VT_0-F(1)-F(2))*(I3_0-F(2))-kminus*(I5_0-F(1))*F(2)+kplus*(I3_0-F(2))*F(1);
end







function [objective, t, F] = odesolver(fitparams)
I5T_0=0;
I3T_0=0;
k5=fitparams(1);
k3=fitparams(2);
kplus=fitparams(3);
kminus=fitparams(4);


[t, F]=ode15s(@twotoeholdODEs, tdata, [I5T_0;I3T_0]);
diff=[(Fdata1(1:fitstopindex)-F(1:fitstopindex,1)).*(logspace(logweight,1,fitstopindex)'),(Fdata2(1:fitstopindex)-F(1:fitstopindex,2)).*(logspace(logweight,1,fitstopindex)')];
if min(fitparams)<0
    impossible=999999999999999999999999999999999999999999999999999;
elseif abs(log(kplus/kminus))>3 %Forwards and backwards rates can't be more than 3 orders of magnitude different (better to use energies but I haven't done this yet)
    impossible=999999999999999999999999999999999999999999999999999;
else
    impossible=0;
end
diff1=norm((diff(:,1)));
diff2=norm((diff(:,2)));
objective = norm((diff(:,1)))+norm((diff(:,2)))+impossible;
end









options = optimset('MaxIter',2000000);
params=fminsearch(@(fitparams) odesolver(fitparams), initfitparams, options);
[obj, t, F] = odesolver(params);

figure
hold on
plot(t,(F(:,1)+F(:,2)), '--', 'Color', [1 0.5 0],'MarkerSize',10)
%plot(t,(F(:,1)+F(:,2)), '.', 'Color', [1 0.5 0],'MarkerSize',18)
plot(t,(Fdata1+Fdata2), '-', 'Color', [1 0.5 0])
%plot(t,F(:,1), 'r.','MarkerSize',18)
plot(t,F(:,1), 'r--','MarkerSize',10)
plot(t,Fdata1, 'r')
%plot(t,F(:,2), 'g.','MarkerSize',18)
plot(t,F(:,2), 'g--','MarkerSize',10)
plot(t,Fdata2, 'g')
file=strsplit(datafilename, '_');
%graphname = strcat(file{1}, ' sample ', num2str(samplenumber));
graphname = 'Insert name of graph here';
title(graphname)
xlabel('Time (s)');
ylabel('Relative fluorescence intensity');

fittedks={strcat('k_5=', num2str(round(k5./(12.5*10^(-9)),3,'significant')), ' M^{-1}s^{-1}'); strcat('k_3=', num2str(round(k3./(12.5*10^(-9)),3,'significant')), ' M^{-1}s^{-1}');strcat('k_53=', num2str(round(kplus./(12.5*10^(-9)),3,'significant')), ' M^{-1}s^{-1}');strcat('k_35=', num2str(round(kminus./(12.5*10^(-9)),3,'significant')), ' M^{-1}s^{-1}')}

%ylim=get(gca,'YLim');
ylim([0 1.1])
%xlim=get(gca,'XLim');
xlim([0 100000])
%text(xlim(2),ylim(2),fittedks,'VerticalAlignment','top','HorizontalAlignment','right');


hold off




end

