function [ jydataprocessed, experimentref, startpointindex] = jytwotoeholdnormalise( filename, startpointsensitivity, mixtime, concI_0, concVT_0, varargin)
%jytwotoeholdnormalise  Takes a transposed output of fluorescence data (use
%function transpose_CWA_text_file to obtain this), divides by the Target saturated control fluorescence in position 4, finds the start point of the experiment and zeros x and y here, and
%rescales data in y to show fraction of Target strand bound invader on y axis [IT]/[T_{Total}].
%   Data should be 8 columns with even columns giving fluorescence counts
%   and odd columns giving time.  The last two columns should contain the
%   Target saturated control trace.
%
% See also transpose_CWA_text_file, merge_transposed_text_file, definecolours2, fit.





%NOTE BOUNDS ON FITTING FUNCTION

%colourcell = definecolours2(3, [1 0 1]);
%%NOTE!!! TOM HAD TO COMMENT THE ABOVE OUT TO MAKE THINGS WORK

% Read in data
datastruct=importdata(filename, '\t');
jydata=datastruct.data;
rawdata=jydata;
samples=datastruct.colheaders

[path experimentname]=fileparts(filename)






% Photobleaching background correction (divide by fluorescence in control
% sample which must be sample 4 (i.e. columns 7 and 8)
secondorderfit=zeros(length(jydata),9);

    
    jydata(:,2)=jydata(:,2)./jydata(:,8); 
    jydata(:,4)=jydata(:,4)./jydata(:,8);
    jydata(:,6)=jydata(:,6)./jydata(:,8);


% Find the startpoint of the reaction
        % First identify discontinuity in data aquisition by finding the
        % difference between adjacent timepoints
        diference=diff(jydata(:,1));
        nonzerodiference=diference(diference~=0);
        timestep = mode(nonzerodiference);
        experimentref={}
        for i=1:3;
            sample=samples{2*i}
            graphname=[experimentname,' position ', num2str(i),': ',sample]
        pauses = diff(jydata(:,(2*i-1)))-timestep;
        pauses = abs(pauses)>0.2; % If the instrument is interrupted (for adding reactants) the hope is it will produce a time difference not equal to timestep. 0.2 provides sufficient tolerance for small variations in timestep occasionally produced by the instrument when acquiring data (particuarly for the late sample positions)
        
        pauses = padarray(pauses,[1,0],'post'); % array needs `padding' because after applying diff the data will be shortened.  One extra zero is added at the end.
        
        
        % User can add a 6th and 7th optional input to define the start and end of a window over
        % which to search for the startpoint of the reaction.  The window
        % is defined in seconds and refers to times in the original data
        % (unshifted)
        if nargin == 7
           
            %Override the start point fitting with user defined "window"
            %variable input
            windowopen=varargin{1}
            windowclose=varargin{2}

            searchstartindex= floor(windowopen/timestep)
            searchstopindex= floor(windowclose/timestep)
            pauses=zeros(length(jydata(:,1)),1);
            pauses(searchstartindex:searchstopindex)=1;
            pauses=logical(pauses);
        end
        
        % For the positions where the instrument pauses (or the user
        % defined window) the maximum local rise is used to determine the
        % start of the reaction.  Input variable startpointsensistivity
        % gives the number of data points to have their differences summed to eventually find a local
        % rise
        riselocal = diff(jydata(:,(2*i))); % Differentiate fluorescence
        rise=[];
        for j=1:(length(riselocal)-startpointsensitivity)
            rise(j) = sum(riselocal(j:(j+startpointsensitivity))); % sum the differences between adjacent data points for the next startpointsensitivity data points
        end
        
        rise=rise';
        
        length(pauses)
        
      
    % find the difference between the rise (over startpointsensitivity
    % points) before a pause and the rise (over startpointsensitivity points)
    % after a pause.  The maximum difference should occur once the reaction
    % has started (i.e. the first data point of the reaction).
        fluor_later = padarray(rise,[(startpointsensitivity+1),0],'post'); % Fluorescence at a later time should be higher
        fluor_earlier = padarray(rise,[(startpointsensitivity+1),0],'pre');
        
        length(fluor_later)
        output_args = fluor_later;

        fwd_jumps = pauses.*fluor_later;
        bwd_jumps = pauses.*fluor_earlier;
        jumps = fwd_jumps-abs(bwd_jumps);
        
        %TOM: I run into some kind of trouble here; number of elements not
        %matching?
        startpointindex(i) = find(jumps == max(jumps((3*startpointsensitivity):(end-3*startpointsensitivity))))
        
        figure('name', graphname)
        plot(jydata((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i-1)),fwd_jumps(2*startpointsensitivity:(end-2*startpointsensitivity)))
        hold on
        plot(jydata((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i-1)),jydata((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i)),'r')
        ylim([0 1.2])
        hold off

        % The user can use an 8th vector input to completely manually define the startpoint which replaces startpointindex
        if nargin > 7
            startpointindex=varargin{3}
        end
       
        % TOM: I run into trouble here because matrix indeces don't match
        experimentstart=jydata(startpointindex(i),(2*i-1))
        


        
        % Now that the start point has been determined it is zeroed (with
        % the user input mixing time as an offset).  The zero point for
        % fluorescence is assumed to be the fluorescence at the point
        % immediately before the start point.
        
        jydataprocessed(:,(2*i-1))=jydata(:,(2*i-1))-jydata(startpointindex(i),(2*i-1))+mixtime;
        jydataprocessed(:,(2*i))=jydata(:,(2*i))-min(jydata(startpointindex(i)-1,(2*i)),jydata(startpointindex(i),(2*i)));
        
        
        
        
        
        
% Extract raw fluorescence counts for IT_saturated (in sample 4) and for I_0
rawI_0=min(rawdata(startpointindex(i)-1,(2*i)),rawdata(startpointindex(i),(2*i)))
%rawIT_sat=median(rawdata(:,8))
rawIT_sat=rawdata(startpointindex(i),8)
% rescaleing to find target bound fraction
jydataprocessed(:,(2*i))=jydataprocessed(:,(2*i))*rawIT_sat/(rawIT_sat-rawI_0);
% rescaling to normalise wrt total target
jydataprocessed(:,(2*i))=jydataprocessed(:,(2*i))*concI_0/concVT_0;

        
        
        

        %figure
        plot(jydataprocessed((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i-1)),jydataprocessed((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i)))
        %, 'Color',colourcell{i}) NOTE: TOM REMOVED THE PRECEEDING TEXT
        %FROM THE FUNCTION TO TRY AND MAKE IT WORK
        title(graphname);
        xlabel('Time (s)');
        ylabel('Fluorescence (a.u.)');

        
        experimentref=[experimentref;{graphname}]
        end

end

