function [ jydataprocessed, experimentref, startpointindex] = jytwotoeholdnormalise( filename, startpointsensitivity, mixtime, concI_0, concVT_0, varargin)
%jytwotoeholdnormalise  Takes a transposed output of fluorescence data (use
%function transpose_CWA_text_file to obtain this), divides by the Target saturated control fluorescence in position 4, finds the start point of the experiment and zeros x and y here, and
%rescales data in y to show fraction of Target strand bound invader on y axis [IT]/[T_{Total}].
%   Data should be 8 columns with even columns giving fluorescence counts
%   and odd columns giving time.  The last two columns should contain the
%   Target saturated control trace.
%
% See also transpose_CWA_text_file, merge_transposed_text_file, definecolours2, fit.


        % The automatic starpoint-finding code has been deleted from this
        % function. The code will therefore only function if fed a 3d vector as an
        % input varargin. 


% Read in data
datastruct=importdata(filename, '\t');
jydata=datastruct.data;
rawdata=jydata;
samples=datastruct.colheaders

[path experimentname]=fileparts(filename)






% Photobleaching background correction (divide by fluorescence in control
% sample which must be sample 4 (i.e. columns 7 and 8)
secondorderfit=zeros(length(jydata),9);

    
    jydata(:,2)=jydata(:,2)./jydata(:,8); 
    jydata(:,4)=jydata(:,4)./jydata(:,8);
    jydata(:,6)=jydata(:,6)./jydata(:,8);


% Find the startpoint of the reaction
        % First identify discontinuity in data aquisition by finding the
        % difference between adjacent timepoints
        diference=diff(jydata(:,1));
        nonzerodiference=diference(diference~=0);
        timestep = mode(nonzerodiference);
        experimentref={}
        for i=1:3;
            sample=samples{2*i}
            graphname=[experimentname,' position ', num2str(i),': ',sample]
    
        
        
   

        
        if nargin > 7
            startpointindex=varargin{3}
        end
        experimentstart=jydata(startpointindex(i),(2*i-1))
        


        
        % Now that the start point has been determined it is zeroed (with
        % the user input mixing time as an offset).  The zero point for
        % fluorescence is assumed to be the fluorescence at the point
        % immediately before the start point.
        
        jydataprocessed(:,(2*i-1))=jydata(:,(2*i-1))-jydata(startpointindex(i),(2*i-1))+mixtime;
        jydataprocessed(:,(2*i))=jydata(:,(2*i))-min(jydata(startpointindex(i)-1,(2*i)),jydata(startpointindex(i),(2*i)));
        
        
        
        
        
        
% Extract raw fluorescence counts for IT_saturated (in sample 4) and for I_0
rawI_0=min(rawdata(startpointindex(i)-1,(2*i)),rawdata(startpointindex(i),(2*i)))
%rawIT_sat=median(rawdata(:,8))
rawIT_sat=rawdata(startpointindex(i),8)
% rescaleing to find target bound fraction
jydataprocessed(:,(2*i))=jydataprocessed(:,(2*i))*rawIT_sat/(rawIT_sat-rawI_0);
% rescaling to normalise wrt total target
jydataprocessed(:,(2*i))=jydataprocessed(:,(2*i))*concI_0/concVT_0;

        
        
        

        %figure
        plot(jydataprocessed((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i-1)),jydataprocessed((2*startpointsensitivity:(end-2*startpointsensitivity)),(2*i)))
        title(graphname);
        xlabel('Time (s)');
        ylabel('Fluorescence (a.u.)');

        
        experimentref=[experimentref;{graphname}]
        end

end

